import stockquotes as sq
import yfinance as yf
import pandas as pd
from NewsScraper import NewsScraper
import datetime

class Stock:
    def __init__(self, symbol):
        self.ticker = symbol.upper()
        self.newsScraper = NewsScraper()
        self.sqobj = sq.Stock(self.ticker)
        self.yfobj = yf.Ticker(self.ticker)
        self.info = self.yfobj.get_info()

    def get_ticker(self):
        return self.ticker

    def get_news(self):
        news = pd.DataFrame(self.newsScraper.get_articles(self.ticker))
        news.columns=['title', 'date', 'URL']
        return news

    def get_month_ema(self):
        df = self.get_last_month_close()
        alpha_val = 2 / (len(df) + 1)
        df = df.iloc[::-1]
        EMA = df.ewm(alpha=alpha_val).mean()
        EMA.columns = ['EMA']
        return EMA

    def get_last_month_data(self):
        df = pd.DataFrame(self.sqobj.historical)
        df.set_index('date', inplace=True)
        return df
    
    def get_last_month_open(self):
        df = self.get_last_month_data()['open'].to_frame()
        df.columns=['open']
        return df        

    def get_last_month_close(self):
        df = self.get_last_month_data()['close'].to_frame()
        df.columns=['close']
        return df  
    
    def get_last_month_high(self):
        df = self.get_last_month_data()['high'].to_frame()
        df.columns=['high']
        return df  

    def get_last_month_low(self):
        df = self.get_last_month_data()['high'].to_frame()
        df.columns=['high']
        return df  
    
    def get_last_month_volume(self):
        df = self.get_last_month_data()['volume'].to_frame()
        df.columns=['volume']
        return df  

    def get_current_price(self):
        return self.sqobj.current_price

    def get_name(self):
        return self.info['longName']

    def get_sector(self):
        return self.info['sector']
    
    def get_industry(self):
        return self.info['industry']

    def get_employees(self):
        return self.info['fullTimeEmployees']
    
    def get_summary(self):
        return self.info['longBusinessSummary']
    
    def get_address(self):
        return (self.info['address1'] + ', ' + self.info['city'] + ', ' + self.info['state'] + ', ' + self.info['zip'] + ', ' + self.info['country'])

    def get_website(self):
        return self.info['website']

    def get_average_volume(self):
        return self.info['averageVolume'] 

    def get_volume(self):
        return self.info['volume']

    def get_dividend_yield(self):
        return self.info['dividendYield']

    def get_day_high(self):
        return self.info['dayHigh']
    
    def get_day_low(self):
        return self.info['dayLow']

    def get_52week_high(self):
        return self.info['fiftyTwoWeekHigh']

    def get_52week_low(self):
        return self.info['fiftyTwoWeekLow']
    
    def get_holders(self):
        return self.yfobj.institutional_holders

    def get_sustainability_info(self):
        return self.yfobj.sustainability

    def get_analyst_recs(self):
        return self.yfobj.recommendations
    
    def get_most_recent_recs(self):
        return self.yfobj.recommendations.tail()


import requests
from bs4 import BeautifulSoup

class NewsScraper():
    def __init__(self):
        pass

    def get_articles(self, ticker):
        '''
        Returns a list of tuples with the title, date, and link to articles about the given company
        '''
        articles = []
        URL = 'https://www.nasdaq.com/market-activity/stocks/' + ticker.lower() + '/news-headlines'
        
        soup = self.get_html(URL)
        results = soup.find_all('li', class_='quote-news-headlines__item')
        for article in results:
            title = article.find('p', class_='quote-news-headlines__item-title')
            date = article.find('span', class_='quote-news-headlines__date')
            link = article.find('a', class_='quote-news-headlines__link')
            article_data = (title.text, date.text, 'https://www.nasdaq.com' + link['href'])
            articles.append(article_data)
        
        return articles

    def get_html(self, URL):
        headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/56.0.2924.76 Safari/537.36', "Upgrade-Insecure-Requests": "1","DNT": "1","Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8","Accept-Language": "en-US,en;q=0.5","Accept-Encoding": "gzip, deflate"}
        page = requests.get(URL, headers=headers)
        soup = BeautifulSoup(page.content, 'html.parser')
        return soup


from distutils.core import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

long_description = "abcdefgh"

setup(
    name='py-stocks',
    packages=['py-stocks'],
    version='1.1',
    license='MIT',
    description="py-stocks is a package for retrieving real-time stock data, historical stock data, and stock technical indicators.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Pranav Addepalli', 
    author_email='pranav.addepalli@gmail.com',
    url='https://github.com/pranavaddepalli/py-stocks',
    download_url='https://github.com/pranavaddepalli/py-stocks/archive/v1.0.tar.gz',
    keywords=['Finance', 'Stocks', 'Python', 'Scraper'],
    install_requires=[
        'stockquotes',
        'yfinance',
        'pandas',
        'beautifulsoup4',
        'datetime',
        'requests',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
